@@ -142,12 +142,12 @@
     <message>
         <location filename="mainwindow.cpp" line="224"/>
         <source>Fix missing dependencies...</source>
-        <translation type="unfinished"/>
+        <translation>Reparar dependências em falta...</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="226"/>
         <source>Error running %1 command</source>
-        <translation type="unfinished"/>
+        <translation>Erro ao executar o comando %1</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="238"/>
